[jboss-cvs] JBossCache/src/org/jboss/cache ...
Brian Stansberry
brian.stansberry at jboss.com
Thu Dec 7 20:24:59 EST 2006
User: bstansberry
Date: 06/12/07 20:24:59
Modified: src/org/jboss/cache Tag: Branch_JBossCache_1_4_0
TreeCache.java
Log:
Don't refer to internal field in Javadoc
Default mux stack should be udp
Revision Changes Path
No revision
No revision
1.195.2.29 +6 -5 JBossCache/src/org/jboss/cache/TreeCache.java
(In the diff below, changes in quantity of whitespace are not shown.)
Index: TreeCache.java
===================================================================
RCS file: /cvsroot/jboss/JBossCache/src/org/jboss/cache/TreeCache.java,v
retrieving revision 1.195.2.28
retrieving revision 1.195.2.29
diff -u -b -r1.195.2.28 -r1.195.2.29
--- TreeCache.java 5 Dec 2006 17:16:35 -0000 1.195.2.28
+++ TreeCache.java 8 Dec 2006 01:24:59 -0000 1.195.2.29
@@ -99,7 +99,7 @@
* @author <a href="mailto:manik at jboss.org">Manik Surtani (manik at jboss.org)</a>
* @author Brian Stansberry
* @author Daniel Huang (dhuang at jboss.org)
- * @version $Id: TreeCache.java,v 1.195.2.28 2006/12/05 17:16:35 msurtani Exp $
+ * @version $Id: TreeCache.java,v 1.195.2.29 2006/12/08 01:24:59 bstansberry Exp $
* <p/>
* @see <a href="http://labs.jboss.com/portal/jbosscache/docs">JBossCache doc</a>
*/
@@ -158,9 +158,9 @@
protected String mux_serviceName = null;
/**
* The JGroups multiplexer stack name, default is "fc-fast-minimalthreads"
*/
- protected String mux_stackName = "fc-fast-minimalthreads";
+ protected String mux_stackName = "udp";
/**
* Is this cache using a channel from the JGroups multiplexer
@@ -5751,8 +5751,9 @@
* Whenever nodes are created, and the global transaction is not null, the created
* nodes have to be added to the transaction's {@link TransactionEntry}
* field.<br>
- * When a lock is acquired on a node, a reference to the lock has to be added to the list
- * of locked nodes in the {@link TransactionEntry#locks} field.
+ * When a lock is acquired on a node, a reference to the lock has to be
+ * {@link TransactionEntry#addLock(IdentityLock) added to the list of locked nodes}
+ * in the {@link TransactionEntry}.
* <p>This operation will also apply different locking to the tree nodes, depending on
* <tt>operation_type</tt>. If it is <tt>read</tt> type, all nodes will be acquired with
* read lock. Otherwise, the operation is <tt>write</tt> type, all parent nodes will be acquired
@@ -158,9 +158,9 @@
protected String mux_serviceName = null;
/**
- * The JGroups multiplexer stack name, default is "fc-fast-minimalthreads"
+ * The JGroups multiplexer stack name, default is "udp"
*/
More information about the jboss-cvs-commits
mailing list